/*
 * Copyright (c) 2023, Cloudera, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

DROP TABLE IF EXISTS HIVE_SRE_VOLUME_${uuid};

CREATE TABLE IF NOT EXISTS HIVE_SRE_VOLUME_${uuid}
(
    DB_NAME         VARCHAR2(MAX),
    TBL_NAME        VARCHAR2(255),
    PARTITION       VARCHAR2(MAX),
    PATH            VARCHAR2(MAX),
    DIR_COUNT       BIGINT,
    FILE_COUNT      BIGINT,
    TOTAL_SIZE      VARCHAR2(255),
    primary key (DB_NAME, TBL_NAME, PARTITION)
    )
AS
SELECT DATABASE DB_NAME, "TABLE" TBL_NAME, CASE WHEN PARTITION IS NULL THEN '' ELSE PARTITION END,  PATH , "Dir. Count" DIR_COUNT, "File Count" FILE_COUNT, "Total Size" TOTAL_SIZE FROM CSVREAD('${path_to_csv_file}');

MERGE INTO HIVE_SRE_VOLUME AS T USING HIVE_SRE_VOLUME_${uuid} AS S
ON T.SOURCE_SERVER_ID = ${sourceServerId} AND T.SOURCE_CLUSTER_ID = '${clusterName}' AND T.DB_NAME = S.DB_NAME AND T.TBL_NAME = S.TBL_NAME AND T.PARTITION = S.PARTITION
WHEN MATCHED THEN
    UPDATE SET T.PATH = S.PATH, T.DIR_COUNT = S.DIR_COUNT, T.FILE_COUNT = S.FILE_COUNT, T.TOTAL_SIZE = S.TOTAL_SIZE
WHEN NOT MATCHED THEN
    INSERT (SOURCE_SERVER_ID, SOURCE_CLUSTER_ID, DB_NAME, TBL_NAME, PARTITION, PATH, DIR_COUNT, FILE_COUNT, TOTAL_SIZE)
    VALUES (${sourceServerId}, '${clusterName}', S.DB_NAME, S.TBL_NAME, S.PARTITION, S.PATH, S.DIR_COUNT, S.FILE_COUNT, S.TOTAL_SIZE);


MERGE INTO HIVE_SRE_RESULT AS T USING (SELECT DISTINCT ${clusterScanExecutionId} as CLUSTER_SCAN_EXECUTION_ID, DB_NAME, TBL_NAME, ${sreCode} AS SRE_CODE FROM HIVE_SRE_VOLUME_${uuid}) AS S
ON T.CLUSTER_SCAN_EXECUTION_ID = S.CLUSTER_SCAN_EXECUTION_ID AND T.DB_NAME = S.DB_NAME AND T.TBL_NAME = S.TBL_NAME AND T.SRE_CODE = S.SRE_CODE
WHEN NOT MATCHED THEN
    INSERT (CLUSTER_SCAN_EXECUTION_ID, DB_NAME, TBL_NAME, SRE_CODE)
    VALUES (S.CLUSTER_SCAN_EXECUTION_ID, S.DB_NAME, S.TBL_NAME, S.SRE_CODE);


DROP TABLE IF EXISTS HIVE_SRE_VOLUME_${uuid};


