#!/bin/bash

SCRIPT_PATH="$(
  cd "$(dirname "$0")" >/dev/null 2>&1 || exit
  pwd -P
)"

LOG_FILE=$(basename "$0" .sh).log

for i in "$@"; do
  case $i in
  -p=* | --profile=*)
    CMA_SERVER_PROFILE=${i#*=}
    ;;
  -j=* | --jdbc-drivers-dir=*)
    JDBC_DRIVERS_DIR=${i#*=}
    ;;
  -jb=* | --jdbc-drivers-backup-dir=*)
      JDBC_DRIVERS_BACKUP_DIR=${i#*=}
      ;;
  -h | --help)
    HELP=true
    ;;

  esac

done

__usage="
 Usage: $(basename "$0") [options]
 Options:
    -j, --jdbc-drivers-dir: Set the jdbc-drivers dir
    -jb, --jdbc-drivers-backup-dir: Set the jdbc-drivers backup dir
    -iv, --image-version: Set the version tag for the docker image
    -p, --profile: Set the active profile(s) for the cma-server
    -h, --help: Print this help
 "

if [ "${HELP}" = true ]; then
  echo "$__usage"
  exit 0
fi

if [ -z "${CMA_SERVER_PROFILE}" ]; then
  echo "--profile must be specified!" | tee -a "$LOG_FILE"
  echo "$__usage" | tee -a "$LOG_FILE"
  exit 1
fi

if [ -z "${JDBC_DRIVERS_DIR}" ]; then
  echo "--jdbc-drivers-dir must be specified!" | tee -a "$LOG_FILE"
  echo "$__usage" | tee -a "$LOG_FILE"
  exit 1
fi

if [ -z "${JDBC_DRIVERS_BACKUP_DIR}" ]; then
  echo "--jdbc-drivers-backup-dir must be specified!" | tee -a "$LOG_FILE"
  echo "$__usage" | tee -a "$LOG_FILE"
  exit 1
fi

# copy jdbc drivers
echo "copying ${JDBC_DRIVERS_BACKUP_DIR} to ${JDBC_DRIVERS_DIR} " | tee -a "$LOG_FILE"
#mkdir -p "${JDBC_DRIVERS_DIR}"
cp -n -r "${JDBC_DRIVERS_BACKUP_DIR}" "${JDBC_DRIVERS_DIR}"

echo "copying Atlas Migration Tool to ${AM2CM_ROOT}" | tee -a "$LOG_FILE"
cp -nr /tmp/atlas_migration_tool/* "$AM2CM_ROOT"

# start server
cma-server.sh --profile="${CMA_SERVER_PROFILE}" --start --docker-mode
